==> LIFEsim-0.2.9.tar.gz: LIFEsim-0.2.9/setup.py <==
import os
from setuptools import setup

setup(
    name='LIFEsim',
    version='0.2.9',
    description='Simulator software for the Large Interferometer For Exoplanets (LIFE)',
    long_description=open('README.rst').read(),
    long_description_content_type='text/x-rst',
    author='Felix Dannert, Maurice Ottiger & Sascha Quanz',
    author_email='fdannert@ethz.ch',
    url='https://github.com/fdannert/LIFEsim',
    project_urls={'Documentation': 'https://lifesim.readthedocs.io'},
    packages=['lifesim',
              'lifesim.core',
              'lifesim.gui',
              'lifesim.instrument',
              'lifesim.optimize',
              'lifesim.util'],
    include_package_data=True,
    install_requires=['astropy==4.2.1; platform_system == "Linux"',
                      'matplotlib==3.4.2; platform_system == "Linux"',
                      'numpy==1.20.3; platform_system == "Linux"',
                      'pandas==1.2.4; platform_system == "Linux"',
                      'PyQt5==5.15.4; platform_system == "Linux"',
                      'tqdm==4.60.0; platform_system == "Linux"',
                      'astropy==4.2; platform_system == "Windows"',
                      'matplotlib==3.3.4; platform_system == "Windows"',
                      'numpy==1.20.2; platform_system == "Windows"',
                      'pandas==1.2.4; platform_system == "Windows"',
                      'pyqt==5.9.2; platform_system == "Windows"',
                      'tqdm==4.59.0; platform_system == "Windows"',
                      'astropy==4.2.1; platform_system == "Darwin"',
                      'matplotlib==3.4.2; platform_system == "Darwin"',
                      'numpy==1.20.3; platform_system == "Darwin"',
                      'pandas==1.2.4; platform_system == "Darwin"',
                      'PyQt5==5.15.4; platform_system == "Darwin"',
                      'tqdm==4.61.0; platform_system == "Darwin"',
                      ],
    license='GPLv3',
    zip_safe=False,
    keywords='lifesim',
    python_requires='~=3.8',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Astronomy',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.8',
    ]
)

==> LIFEsim-0.2.11.tar.gz: LIFEsim-0.2.11/setup.py <==
import os
from setuptools import setup

setup(
    name='LIFEsim',
    version='0.2.11',
    description='Simulator software for the Large Interferometer For Exoplanets (LIFE)',
    long_description=open('README.rst').read(),
    long_description_content_type='text/x-rst',
    author='Felix Dannert, Maurice Ottiger & Sascha Quanz',
    author_email='fdannert@ethz.ch',
    url='https://github.com/fdannert/LIFEsim',
    project_urls={'Documentation': 'https://lifesim.readthedocs.io'},
    packages=['lifesim',
              'lifesim.core',
              'lifesim.gui',
              'lifesim.instrument',
              'lifesim.optimize',
              'lifesim.util'],
    include_package_data=True,
    install_requires=['astropy==4.2.1; platform_system == "Linux"',
                      'matplotlib==3.4.2; platform_system == "Linux"',
                      'numpy==1.20.3; platform_system == "Linux"',
                      'pandas==1.2.4; platform_system == "Linux"',
                      'PyQt5==5.15.4; platform_system == "Linux"',
                      'tqdm==4.60.0; platform_system == "Linux"',
                      'astropy==4.2.1; platform_system == "Windows"',
                      'matplotlib==3.4.2; platform_system == "Windows"',
                      'numpy==1.20.3; platform_system == "Windows"',
                      'pandas==1.2.4; platform_system == "Windows"',
                      'PyQt5==5.15.4; platform_system == "Windows"',
                      'tqdm==4.61.0; platform_system == "Windows"',
                      'astropy==4.2.1; platform_system == "Darwin"',
                      'matplotlib==3.4.2; platform_system == "Darwin"',
                      'numpy==1.20.3; platform_system == "Darwin"',
                      'pandas==1.2.4; platform_system == "Darwin"',
                      'PyQt5==5.15.4; platform_system == "Darwin"',
                      'tqdm==4.61.0; platform_system == "Darwin"',
                      ],
    license='GPLv3',
    zip_safe=False,
    keywords='lifesim',
    python_requires='~=3.8',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Astronomy',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.8',
    ]
)
